@@ -7,24 +7,21 @@
 #ifndef COMMON_DATABASE_H
 #define COMMON_DATABASE_H
 
-#include <utils/d_ptr.h>
-#include <memory>
 #include <QSqlQuery>
+#include <memory>
+#include <utils/d_ptr.h>
 
-namespace Common {
+namespace Common
+{
 
-class Database {
+class Database
+{
 public:
     typedef std::shared_ptr<Database> Ptr;
 
-    enum Source {
-        ResourcesDatabase
-    };
+    enum Source { ResourcesDatabase };
 
-    enum OpenMode {
-        ReadWrite,
-        ReadOnly
-    };
+    enum OpenMode { ReadWrite, ReadOnly };
 
     static Ptr instance(Source source, OpenMode openMode);
 
@@ -43,7 +40,8 @@ public:
     Database();
 
     friend class Locker;
-    class Locker {
+    class Locker
+    {
     public:
         explicit Locker(Database &database);
         ~Locker();
@@ -52,32 +50,28 @@ public:
         QSqlDatabase &m_database;
     };
 
-#define DATABASE_TRANSACTION(A) \
-        /* enable this for debugging only: qDebug() << "Location:" << __FILE__ << __LINE__; */ \
-        Common::Database::Locker lock(A)
+#define DATABASE_TRANSACTION(A)                                                                                                                                \
+    /* enable this for debugging only: qDebug() << "Location:" << __FILE__ << __LINE__; */                                                                     \
+    Common::Database::Locker lock(A)
 
 private:
     D_PTR;
 };
 
-template <typename EscapeFunction>
-QString parseStarPattern(const QString &pattern, const QString &joker,
-                         EscapeFunction escape)
+template<typename EscapeFunction>
+QString parseStarPattern(const QString &pattern, const QString &joker, EscapeFunction escape)
 {
-    const auto begin     = pattern.constBegin();
-    const auto end       = pattern.constEnd();
+    const auto begin = pattern.constBegin();
+    const auto end = pattern.constEnd();
 
-    auto currentStart    = pattern.constBegin();
+    auto currentStart = pattern.constBegin();
     auto currentPosition = pattern.constBegin();
 
     bool isEscaped = false;
 
     // This should be available in the QString class...
-    auto stringFromIterators = [&](const QString::const_iterator &currentStart,
-    const QString::const_iterator &currentPosition) {
-        return pattern.mid(
-                   std::distance(begin, currentStart),
-                   std::distance(currentStart, currentPosition));
+    auto stringFromIterators = [&](const QString::const_iterator &currentStart, const QString::const_iterator &currentPosition) {
+        return pattern.mid(std::distance(begin, currentStart), std::distance(currentStart, currentPosition));
     };
 
     // Escaping % and _ for sql like
@@ -99,8 +93,7 @@ QString parseStarPattern(const QString &pattern, const QString &joker,
 
         } else if (*currentPosition == '*') {
             // Replacing the star with the sql like joker - %
-            resultPattern.append(escape(stringFromIterators(
-                                            currentStart, currentPosition)) + joker);
+            resultPattern.append(escape(stringFromIterators(currentStart, currentPosition)) + joker);
             currentStart = currentPosition + 1;
 
         } else {
@@ -109,8 +102,7 @@ QString parseStarPattern(const QString &pattern, const QString &joker,
     }
 
     if (currentStart != currentPosition) {
-        resultPattern.append(escape(stringFromIterators(
-                                        currentStart, currentPosition)));
+        resultPattern.append(escape(stringFromIterators(currentStart, currentPosition)));
     }
 
     return resultPattern;
@@ -118,7 +110,7 @@ QString parseStarPattern(const QString &pattern, const QString &joker,
 
 inline QString starPatternToLike(const QString &pattern)
 {
-    return parseStarPattern(pattern, QStringLiteral("%"), [] (QString str) {
+    return parseStarPattern(pattern, QStringLiteral("%"), [](QString str) {
         return str.replace(QLatin1String("%"), QLatin1String("\\%")).replace(QLatin1String("_"), QLatin1String("\\_"));
     });
 }
@@ -126,4 +118,3 @@ inline QString starPatternToLike(const QString &pattern)
 } // namespace Common
 
 #endif // COMMON_DATABASE_H
-
